==> Tegra_Multimedia_API_R24.2.1_aarch64.tbz2: tegra_multimedia_api/argus/apps/camera/docs/doxygen/html/search/functions_67.js <==
var searchData=
[
  ['gainrange',['gainRange',['../classArgusSamples_1_1AppModuleGeneric.html#add190d9d9221ae01bd744a6eec3b3e54',1,'ArgusSamples::AppModuleGeneric']]],
  ['galleryitem',['GalleryItem',['../classArgusSamples_1_1GalleryItem.html#ab1ae78ddbdd4ff2378aadb257c3905f6',1,'ArgusSamples::GalleryItem::GalleryItem(const char *fileName, time_t modTime)'],['../classArgusSamples_1_1GalleryItem.html#ae1452d1184491c7ab8bd770e6e905bcb',1,'ArgusSamples::GalleryItem::GalleryItem()']]],
  ['galleryitemimage',['GalleryItemImage',['../classArgusSamples_1_1GalleryItemImage.html#a5c00165c0add390ba455bfc48dc21068',1,'ArgusSamples::GalleryItemImage']]],
  ['galleryitemvideo',['GalleryItemVideo',['../classArgusSamples_1_1GalleryItemVideo.html#ade37284d0655d9ddfe733bb72d4f724f',1,'ArgusSamples::GalleryItemVideo']]],
  ['gallerythread',['GalleryThread',['../classArgusSamples_1_1GalleryThread.html#a26d24564ff889340fe8990a864f59477',1,'ArgusSamples::GalleryThread']]],
  ['get',['get',['../classArgusSamples_1_1GstUnrefer.html#a2eef3eb9fc6cfb71c57788cea4d4178d',1,'ArgusSamples::GstUnrefer']]],
  ['getaspectratio',['getAspectRatio',['../classArgusSamples_1_1VideoPipeline.html#afd8697188b988e814b98dc634453a654',1,'ArgusSamples::VideoPipeline']]],
  ['getcomposercontext',['getComposerContext',['../classArgusSamples_1_1Renderer.html#a0b626f7160eb939e976d943d88ce323c',1,'ArgusSamples::Renderer']]],
  ['getcontext',['getContext',['../classArgusSamples_1_1Composer.html#a45aa8893543a27ef016f8b2e3b47955c',1,'ArgusSamples::Composer']]],
  ['getcurrenttime',['getCurrentTime',['../namespaceArgusSamples.html#aabd2eb9c698c8f52b1ec2fa287e0908d',1,'ArgusSamples']]],
  ['getdata',['getData',['../classArgusSamples_1_1GalleryItemImage.html#aefcafe95f70b7a0d58a3f33a05be7381',1,'ArgusSamples::GalleryItemImage']]],
  ['getdevicecount',['getDeviceCount',['../classArgusSamples_1_1Dispatcher.html#afb00309553d55ef37c1e2f2245c777f4',1,'ArgusSamples::Dispatcher']]],
  ['getdevicefocuspositionrange',['getDeviceFocusPositionRange',['../classArgusSamples_1_1Dispatcher.html#abfeb9bf507628bcc70c3b685fe76c311',1,'ArgusSamples::Dispatcher']]],
  ['getegldisplay',['getEGLDisplay',['../classArgusSamples_1_1Renderer.html#af0acede010bf418e92a6ee3704cee9b5',1,'ArgusSamples::Renderer']]],
  ['geteglstream',['getEGLStream',['../classArgusSamples_1_1GalleryItemVideo.html#a6f96989bf7ee3efb307f51bdd34a0fde',1,'ArgusSamples::GalleryItemVideo']]],
  ['getfileextension',['getFileExtension',['../classArgusSamples_1_1VideoPipeline.html#a6bd711d871b1f3d3a63b532c77d714da',1,'ArgusSamples::VideoPipeline']]],
  ['getfilename',['getFileName',['../classArgusSamples_1_1GalleryItem.html#a1257150c9eaf6aba937a0cdc3d65147f',1,'ArgusSamples::GalleryItem']]],
  ['getheight',['getHeight',['../classArgusSamples_1_1GalleryItemImage.html#a5e5ce4987cd3a3f9ca530bb17963b9c8',1,'ArgusSamples::GalleryItemImage']]],
  ['getinfo',['getInfo',['../classArgusSamples_1_1Dispatcher.html#a336bef8e2a26de1e0f5d1ea85cb599f6',1,'ArgusSamples::Dispatcher']]],
  ['getinstance',['getInstance',['../classArgusSamples_1_1Dispatcher.html#a27c03ac9165a07afd38f5bdc27ac275e',1,'ArgusSamples::Dispatcher::getInstance()'],['../classArgusSamples_1_1Renderer.html#ac3b8f5a8ae233f7544f463e01605e8b5',1,'ArgusSamples::Renderer::getInstance()']]],
  ['getoutputsize',['getOutputSize',['../classArgusSamples_1_1Dispatcher.html#aaa8dba4f40a0044d3260bb285e9db05a',1,'ArgusSamples::Dispatcher']]],
  ['getoutputstream',['getOutputStream',['../classArgusSamples_1_1GalleryThread.html#a7cba48026b0b5bf7c289c9ced777b7c9',1,'ArgusSamples::GalleryThread']]],
  ['getpthreadmutex',['getPThreadMutex',['../classArgusSamples_1_1Mutex.html#a454e4397e737c4ee8e1bed8c43e24e10',1,'ArgusSamples::Mutex']]],
  ['getsensormode',['getSensorMode',['../classArgusSamples_1_1Dispatcher.html#a4743dad610a1a11955df10f2bb816e7f',1,'ArgusSamples::Dispatcher']]],
  ['getstreamaspectratio',['getStreamAspectRatio',['../classArgusSamples_1_1StreamConsumer.html#ae93d5a2f0e1ecaa4e7fd4ab29c7bbc7d',1,'ArgusSamples::StreamConsumer']]],
  ['getstreamtextureid',['getStreamTextureID',['../classArgusSamples_1_1StreamConsumer.html#ac618fbb6ec2fd0cb953725eaed9f5068',1,'ArgusSamples::StreamConsumer']]],
  ['getstreamtexturemutex',['getStreamTextureMutex',['../classArgusSamples_1_1StreamConsumer.html#ab07fe86ca4a67300f27711720b2d7a4e',1,'ArgusSamples::StreamConsumer']]],
  ['gettype',['getType',['../classArgusSamples_1_1GalleryItem.html#a13c2129c83685b4906b7ac833698b78a',1,'ArgusSamples::GalleryItem::getType()'],['../classArgusSamples_1_1GalleryItemImage.html#acb1e5fc3e059cc8576af3783a5989a8b',1,'ArgusSamples::GalleryItemImage::getType()'],['../classArgusSamples_1_1GalleryItemVideo.html#a92484bcee6f5b81c1b51b3fd7f1dee90',1,'ArgusSamples::GalleryItemVideo::getType()']]],
  ['getwidth',['getWidth',['../classArgusSamples_1_1GalleryItemImage.html#a3cce8d4f3e91bc05b2e0653907c04740',1,'ArgusSamples::GalleryItemImage']]],
  ['gstunrefer',['GstUnrefer',['../classArgusSamples_1_1GstUnrefer.html#a7072ba6bfe7cf2ce3efde28082e409c6',1,'ArgusSamples::GstUnrefer::GstUnrefer(T *p)'],['../classArgusSamples_1_1GstUnrefer.html#a5d2e795daba5a6d1d12ad2ee1461605b',1,'ArgusSamples::GstUnrefer::GstUnrefer()'],['../classArgusSamples_1_1GstUnrefer.html#a0d521b0e8e4a4896f5dfcedec0bf8034',1,'ArgusSamples::GstUnrefer::GstUnrefer(GstUnrefer &amp;other)']]]
];

==> Tegra_Multimedia_API_R27.1.0_aarch64.tbz2: tegra_multimedia_api/argus/apps/camera/docs/doxygen/html/search/functions_67.js <==
var searchData=
[
  ['gainrange',['gainRange',['../classArgusSamples_1_1AppModuleGeneric.html#add190d9d9221ae01bd744a6eec3b3e54',1,'ArgusSamples::AppModuleGeneric']]],
  ['galleryitem',['GalleryItem',['../classArgusSamples_1_1GalleryItem.html#ab1ae78ddbdd4ff2378aadb257c3905f6',1,'ArgusSamples::GalleryItem::GalleryItem(const char *fileName, time_t modTime)'],['../classArgusSamples_1_1GalleryItem.html#ae1452d1184491c7ab8bd770e6e905bcb',1,'ArgusSamples::GalleryItem::GalleryItem()']]],
  ['galleryitemimage',['GalleryItemImage',['../classArgusSamples_1_1GalleryItemImage.html#a5c00165c0add390ba455bfc48dc21068',1,'ArgusSamples::GalleryItemImage']]],
  ['galleryitemvideo',['GalleryItemVideo',['../classArgusSamples_1_1GalleryItemVideo.html#ade37284d0655d9ddfe733bb72d4f724f',1,'ArgusSamples::GalleryItemVideo']]],
  ['gallerythread',['GalleryThread',['../classArgusSamples_1_1GalleryThread.html#a26d24564ff889340fe8990a864f59477',1,'ArgusSamples::GalleryThread']]],
  ['get',['get',['../classArgusSamples_1_1GstUnrefer.html#a2eef3eb9fc6cfb71c57788cea4d4178d',1,'ArgusSamples::GstUnrefer::get()'],['../classArgusSamples_1_1TrackedUniqueObj.html#aa1bd2ace6028d9e18416cdc3f9d226d7',1,'ArgusSamples::TrackedUniqueObj::get()']]],
  ['getaspectratio',['getAspectRatio',['../classArgusSamples_1_1VideoPipeline.html#afd8697188b988e814b98dc634453a654',1,'ArgusSamples::VideoPipeline']]],
  ['getcomposercontext',['getComposerContext',['../classArgusSamples_1_1Renderer.html#a0b626f7160eb939e976d943d88ce323c',1,'ArgusSamples::Renderer']]],
  ['getcontext',['getContext',['../classArgusSamples_1_1Composer.html#a45aa8893543a27ef016f8b2e3b47955c',1,'ArgusSamples::Composer']]],
  ['getcurrenttime',['getCurrentTime',['../namespaceArgusSamples.html#aabd2eb9c698c8f52b1ec2fa287e0908d',1,'ArgusSamples']]],
  ['getdata',['getData',['../classArgusSamples_1_1GalleryItemImage.html#aefcafe95f70b7a0d58a3f33a05be7381',1,'ArgusSamples::GalleryItemImage']]],
  ['getdevicecount',['getDeviceCount',['../classArgusSamples_1_1Dispatcher.html#afb00309553d55ef37c1e2f2245c777f4',1,'ArgusSamples::Dispatcher']]],
  ['getdevicefocuspositionrange',['getDeviceFocusPositionRange',['../classArgusSamples_1_1Dispatcher.html#abfeb9bf507628bcc70c3b685fe76c311',1,'ArgusSamples::Dispatcher']]],
  ['getegldisplay',['getEGLDisplay',['../classArgusSamples_1_1Renderer.html#af0acede010bf418e92a6ee3704cee9b5',1,'ArgusSamples::Renderer']]],
  ['geteglstream',['getEGLStream',['../classArgusSamples_1_1GalleryItemVideo.html#a6f96989bf7ee3efb307f51bdd34a0fde',1,'ArgusSamples::GalleryItemVideo']]],
  ['getfileextension',['getFileExtension',['../classArgusSamples_1_1VideoPipeline.html#a6bd711d871b1f3d3a63b532c77d714da',1,'ArgusSamples::VideoPipeline']]],
  ['getfilename',['getFileName',['../classArgusSamples_1_1GalleryItem.html#a1257150c9eaf6aba937a0cdc3d65147f',1,'ArgusSamples::GalleryItem']]],
  ['getheight',['getHeight',['../classArgusSamples_1_1GalleryItemImage.html#a5e5ce4987cd3a3f9ca530bb17963b9c8',1,'ArgusSamples::GalleryItemImage']]],
  ['getinfo',['getInfo',['../classArgusSamples_1_1Dispatcher.html#a336bef8e2a26de1e0f5d1ea85cb599f6',1,'ArgusSamples::Dispatcher']]],
  ['getinstance',['getInstance',['../classArgusSamples_1_1Dispatcher.html#a27c03ac9165a07afd38f5bdc27ac275e',1,'ArgusSamples::Dispatcher::getInstance()'],['../classArgusSamples_1_1Renderer.html#ac3b8f5a8ae233f7544f463e01605e8b5',1,'ArgusSamples::Renderer::getInstance()']]],
  ['getoutputsize',['getOutputSize',['../classArgusSamples_1_1Dispatcher.html#acf3c377c9e25ba7d2bf03b463b24e572',1,'ArgusSamples::Dispatcher']]],
  ['getoutputstream',['getOutputStream',['../classArgusSamples_1_1GalleryThread.html#a7cba48026b0b5bf7c289c9ced777b7c9',1,'ArgusSamples::GalleryThread']]],
  ['getpthreadmutex',['getPThreadMutex',['../classArgusSamples_1_1Mutex.html#a454e4397e737c4ee8e1bed8c43e24e10',1,'ArgusSamples::Mutex']]],
  ['getsensormode',['getSensorMode',['../classArgusSamples_1_1Dispatcher.html#a4743dad610a1a11955df10f2bb816e7f',1,'ArgusSamples::Dispatcher']]],
  ['getstreamaspectratio',['getStreamAspectRatio',['../classArgusSamples_1_1StreamConsumer.html#ae93d5a2f0e1ecaa4e7fd4ab29c7bbc7d',1,'ArgusSamples::StreamConsumer']]],
  ['getstreamtextureid',['getStreamTextureID',['../classArgusSamples_1_1StreamConsumer.html#ac618fbb6ec2fd0cb953725eaed9f5068',1,'ArgusSamples::StreamConsumer']]],
  ['getstreamtexturemutex',['getStreamTextureMutex',['../classArgusSamples_1_1StreamConsumer.html#ab07fe86ca4a67300f27711720b2d7a4e',1,'ArgusSamples::StreamConsumer']]],
  ['gettype',['getType',['../classArgusSamples_1_1GalleryItem.html#a13c2129c83685b4906b7ac833698b78a',1,'ArgusSamples::GalleryItem::getType()'],['../classArgusSamples_1_1GalleryItemImage.html#acb1e5fc3e059cc8576af3783a5989a8b',1,'ArgusSamples::GalleryItemImage::getType()'],['../classArgusSamples_1_1GalleryItemVideo.html#a92484bcee6f5b81c1b51b3fd7f1dee90',1,'ArgusSamples::GalleryItemVideo::getType()']]],
  ['getwidth',['getWidth',['../classArgusSamples_1_1GalleryItemImage.html#a3cce8d4f3e91bc05b2e0653907c04740',1,'ArgusSamples::GalleryItemImage']]],
  ['gstunrefer',['GstUnrefer',['../classArgusSamples_1_1GstUnrefer.html#a7072ba6bfe7cf2ce3efde28082e409c6',1,'ArgusSamples::GstUnrefer::GstUnrefer(T *p)'],['../classArgusSamples_1_1GstUnrefer.html#a5d2e795daba5a6d1d12ad2ee1461605b',1,'ArgusSamples::GstUnrefer::GstUnrefer()'],['../classArgusSamples_1_1GstUnrefer.html#a0d521b0e8e4a4896f5dfcedec0bf8034',1,'ArgusSamples::GstUnrefer::GstUnrefer(GstUnrefer &amp;other)']]]
];
